#
# spec file for package rt-tests
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rt-tests
VCS: https://src.suse.de/SLFO-pool/rt-tests#8739e0dfec3989e3e8c37df611ab8526e935c4a94929cf5bacc48640839b4a74
Version:        2.8
Release:        160000.1.4
Summary:        Realtime Kernel Testsuite
License:        GPL-2.0-only
Group:          System/Benchmark
URL:            https://git.kernel.org/pub/scm/utils/rt-tests/rt-tests.git
Source0:        https://git.kernel.org/pub/scm/utils/rt-tests/rt-tests.git/snapshot/rt-tests-%{version}.tar.gz
BuildRequires:  libnuma-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base
Conflicts:      hackbench

%description
The Realtime Kernel Testsuite measures real-time attributes of the kernel,
specifically timer and signal latency and the functionality of Priority
Inheritance Mutexes.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags}"
%make_build

%install
%make_install prefix=%{_prefix}
rm -rf %{buildroot}%{_prefix}/src/backfire

%files
%license COPYING
%doc MAINTAINERS README.markdown
%{_bindir}/cyclicdeadline
%{_bindir}/cyclictest
%{_bindir}/get_cyclictest_snapshot
%{_bindir}/deadline_test
%{_bindir}/hackbench
%{_bindir}/hwlatdetect
%{_bindir}/pi_stress
%{_bindir}/pip_stress
%{_bindir}/pmqtest
%{_bindir}/ptsematest
%{_bindir}/queuelat
%{_bindir}/rt-migrate-test
%{_bindir}/signaltest
%{_bindir}/sigwaittest
%{_bindir}/svsematest
%{_bindir}/ssdd
%{_bindir}/oslat
%{_bindir}/determine_maximum_mpps.sh
%{python3_sitelib}/hwlatdetect.py
%{python3_sitelib}/get_cyclictest_snapshot.py
%{_mandir}/man8/cyclictest.8%{?ext_man}
%{_mandir}/man8/hackbench.8%{?ext_man}
%{_mandir}/man8/hwlatdetect.8%{?ext_man}
%{_mandir}/man8/pi_stress.8%{?ext_man}
%{_mandir}/man8/pmqtest.8%{?ext_man}
%{_mandir}/man8/ptsematest.8%{?ext_man}
%{_mandir}/man8/rt-migrate-test.8%{?ext_man}
%{_mandir}/man8/signaltest.8%{?ext_man}
%{_mandir}/man8/sigwaittest.8%{?ext_man}
%{_mandir}/man8/svsematest.8%{?ext_man}
%{_mandir}/man8/ssdd.8%{?ext_man}
%{_mandir}/man8/queuelat.8%{?ext_man}
%{_mandir}/man8/pip_stress.8%{?ext_man}
%{_mandir}/man8/deadline_test.8%{?ext_man}
%{_mandir}/man8/cyclicdeadline.8%{?ext_man}
%{_mandir}/man8/get_cyclictest_snapshot.8%{?ext_man}
%{_mandir}/man8/oslat.8%{?ext_man}
%{_mandir}/man8/determine_maximum_mpps.8%{?ext_man}

%changelog
* Wed Jan  8 2025 pvorel@suse.cz
- Update to version 2.8:
  https://lore.kernel.org/linux-rt-users/20241128215059.40116-1-jkacur@redhat.com/
* Wed Jan  8 2025 pvorel@suse.cz
- Revert back to tar.gz from git.kernel.org (2.7 was moved to "older" subfolder
  in https://mirrors.kernel.org, it shows it's not stable URL).
* Tue Jul 23 2024 pvorel@suse.cz
- Fix archive URL
* Sun Jul  7 2024 pvorel@suse.cz
- Update to version 2.7:
  https://lore.kernel.org/linux-rt-users/20240507144229.42909-1-jkacur@redhat.com/
- Start using xz tarball (instead of gz)
* Wed Jan 31 2024 andrea.manzini@suse.com
- Update to version 2.6:
  https://lore.kernel.org/linux-rt-users/20231006200345.53658-1-jkacur@redhat.com/
* Tue Apr 18 2023 mpluskal@suse.com
- Update to version 2.5:
  https://lore.kernel.org/linux-rt-users/20230120205220.26218-1-jkacur@redhat.com/T/#u
- Drop upstreamed patches:
  * 0001-cyclictest-Fix-threads-being-affined-even-when-a-isn.patch
  * 0002-rt-tests-Remove-arbitrary-num-of-threads-limits.patch
  * 0003-rt-tests-hackbench-Add-error-checking-to-connect-and.patch
  * 0004-rt-tests-hwlatdetect-Update-to-integer-division.patch
* Fri Nov 25 2022 mpluskal@suse.com
- Use sources which are actually published
* Thu Nov 24 2022 pvorel@suse.cz
- Update to upstream version v2.4
  https://lore.kernel.org/linux-rt-users/20220708150017.13462-1-jkacur@redhat.com/
- Update to upstream version v2.3
  https://lore.kernel.org/linux-rt-users/20211210184649.11084-1-jkacur@redhat.com/
- Remove old patch rt-tests-1.10-Makefile.patch, which installed
  src/cyclictest/get_cyclictest_snapshot.8. Upstream guarded it with PYLIB in
  3d1976b ("Makefile: manpages: only add get_cyclictest_snapshot if PYLIB")
  but PYLIB should be defined due BuildRequires:  python3-base
- Backport runtime fixes from upcomming release:
  * 0001-cyclictest-Fix-threads-being-affined-even-when-a-isn.patch
  * 0002-rt-tests-Remove-arbitrary-num-of-threads-limits.patch
  * 0003-rt-tests-hackbench-Add-error-checking-to-connect-and.patch
  * 0004-rt-tests-hwlatdetect-Update-to-integer-division.patch
- Use %%autosetup (not having to add -p1 for patches)
* Tue Aug 31 2021 daniel.wagner@suse.com
- Update to upstream version v2.2
  * signaltest: Fix JSON output latency values for 32bit machines
  * oslat: Don't take trace_threshold into account during preheat
  * sched_deadline: Update HRTICK_DL location
  * Allow static builds by dropping dependency on pthread_getaffinity_np
* Thu Jul 29 2021 daniel.wagner@suse.com
- Enable build on all architectures.
* Wed Jun 30 2021 daniel.wagner@suse.com
- Update to upstream version 2.1
  * Avoid pagefault at startup which made the first cycle
    in cyclictest measure a huge latency spike.
* Fri Jun 25 2021 daniel.wagner@suse.com
- Update to upstream version 2.0
  * All test programs can output their results in JSON format
  * cyclictest: Allow to specify main thread affinity
* Tue Jan  5 2021 jcheung@suse.com
- Update to upstream version 1.10 (SLE-12981)
  * rt-tests: queuelat: Remove get_cpuinfo_mhz.sh and old Makefile
  * rt-tests: determine_maximum_mpps.sh: Add a menu to get user settings.
  * rt-numa: Introduce NUMA helpers
  * cyclictest: Only report the first incident
  * Streamline usage and man page
- Add rt-tests-1.10-Makefile.patch and remove  rt-tests-1.6-Makefile.patch
- Cleanup spec file
- Changes from version 1.9
  * signaltest: Only print from the first thread stats when quiet
  * rt-tests: cyclictest: Move ftrace helpers into rt-utils.[ch]
  * pi_stress: limit the number of inversion groups to the number of online cores
  * rt-tests: Install new man page get_cyclictest_snapshot.8
  * rt-tests: Add a man page for get_cyclictest_snapshot
  * rt-tests: ptsematest.8: Update the ptsematest man page
  * rt-tests: improvements to the python style in get_cyclictest_snapshot
  * cyclictest: Fix setaffinity error on large NUMA machines
- Changes from version 1.8
  * cyclictest: Make the affinity mask apply to the main thread too
  * Remove support for compiling without NUMA
  * cyclictest: Only run on runtime affinity and user supplied affinity
  * cyclictest: Only run on available cpus according to the affinity
  * cyclictest: Report all errors from pthread_setaffinity_np
- Changes from version 1.7
  * Add get_cyclictest_snapshot to Makefile
  * Add the get_cyclictest_snapshot.py utility
  * determine_maximum_mpps.sh: Fix quoting and other shell issue
  * queuelat: get_cpuinfo_mhz.sh highest value
  * cyclicdeadline: Add a simple manpage for cyclicdeadline
* Tue Jun 16 2020 jcheung@suse.com
- Update to version 1.6:
  * New feature to get a snapshot of a running instance of cyclictest without stopping it by
    sending SIGUSR2 to the PID and reading a shared memory segment. This is especially useful
    if running cyclictest over a long period of time
  * Add SPDX tags V3
  * Some fixes
- Changes from version 1.5
  * Mostly small clean-ups and bug fixes
- Changes from version 1.4
  * Added a number of new programs to the rt-tests suite
  - queuelat : simulates a network queue checking for latency violations in packet processing.
  - cyclicdeadline : used to test the deadline scheduler (SCHED_DEADLINE)
  - deadline_test : tests the deadline scheduler in a cyclictest manner
  - ssdd : a tracer to do a bunch of PTRACE_SINGLESTEPs
- Add rt-tests-1.6-Makefile.patch
* Thu Sep 13 2018 jengelh@inai.de
- Fix grammar in description.
- Have some more %%make_install.
* Thu Sep 13 2018 mpluskal@suse.com
- Update to version 1.3
- Cleanup spec file
* Thu Sep 13 2018 jcheung@suse.com
- This is initial to SLERT15 SP1 [fate#326547]
* Mon Jul 30 2018 jcheung@suse.com
- Update to 1.0
  Fate#323312 - Upgrade rt-tests to v1.0
  cyclictest: stop any tracing after hitting a breaktrace threshold
  rt-tests: Makefile: Assume numa_parse_cpustring_all available
  rt-tests: Add man page for rt-migrate-test
  rt-tests: Update the cyclictest man page
  rt-tests: Add missing option to hwlatdetect man page
  rt-tests: Housekeeping fix some spelling errors.
  rt-tests: hwlat.txt: smidetect renamed to hwlatdetect
  rt-tests: Remove doc/release-checklist.txt
  rt-tests: Makefile - bump version to 1.0
* Fri Jul 27 2018 jcheung@suse.com
- Submit to SLERT12 SP4
* Tue Apr 25 2017 jcheung@suse.com
- Submit to SLERT12-SP3
* Thu Dec  8 2016 jcheung@suse.com
- Apply this version to SLE-12-SP2
* Thu Jan 14 2016 jcheung@suse.com
- Apply this version to SLE-12-SP1
* Fri Jul 10 2015 jcheung@suse.com
-
- Add the "COPYING" file in the %%doc section
-
* Thu Jul  9 2015 jcheung@suse.com
-
- license update: GPL-2.0
- We now use SPDX license sytnax.
-
* Wed Jul  8 2015 cdenicolo@suse.com
-
- license update: GPL-2.0
- please use SPDX  license sytnax.
* Tue Jun 30 2015 mgalbraith@suse.de
- Update to 0.89
  This is the last release suitable for SLE11
- Drop legacy/unbuildable backfire/sendme
- Drop legacy SLERT10 scripts
- We now ship virgin source with only hwlatency detect and broken
  legacy code removed.
* Thu Nov 24 2011 mgalbraith@suse.de
- Fix up spec file BuildRequires/Requires for libnuma
* Thu Nov 24 2011 mgalbraith@suse.de
- Update to 0.83
* Fri Aug  6 2010 mgalbraith@suse.de
- Update to 0.72
- Update signaltest display and trace capability to match cyclictest,
  and provide a man page for same.
* Fri Feb 26 2010 jblunck@suse.de
- Update to 0.64.
* Mon Oct 12 2009 sdietrich@suse.de
- Update to 0.53.
* Tue Jul  7 2009 sdietrich@suse.de
- Update to 0.47.
* Mon Jul  6 2009 sdietrich@suse.de
- Update to 0.46. Drop: histogram_exceed_limit.patch
* Thu Jul  2 2009 sdietrich@suse.de
- Update to 0.45. Drop:
  change-output-format-to-allow-6-digits.patch
  clock_nanosleep_interrupt.patch
* Thu Jul  2 2009 sdietrich@suse.de
- Rework Suse-added patches after sending upstream.
  - Fold re-introduce-HIST_MAX-and-silently-cap-the-histogram.patch
  into histogram_exceed_limit.patch.
  - Add proper explanation to change-output-format-to-allow-6-digits.patch
* Mon Jun 29 2009 sdietrich@suse.de
- Update to 0.43
* Thu Jun 25 2009 sdietrich@suse.de
- Update to 0.42
* Tue Apr  7 2009 sdietrich@suse.de
- Update to v. 0.34.
* Thu Aug 21 2008 dgollub@suse.de
- cyclictest_make_all_thread_intervals_equal_for_histogram.patch:
  Change thread interal for histogram mode
* Thu Aug 21 2008 dgollub@suse.de
- updated histogram_exceed_limit.patch:
  Sample doomsday spikes which exceed histogram limit in last bucket
* Tue Aug 19 2008 dgollub@suse.de
- histogram_exceed_limit.patch: handled histogram limit exceed
* Wed Jul 16 2008 dgollub@suse.de
- updated to rt-tests 0.24
  * mlockall option got added (removed mlockall patches)
- cyclictest: fixed staggering of priorities for multiple threads
  bnc#408421
* Tue Jul  8 2008 dgollub@suse.de
- updated to rt-tests 0.23
  * fixed processing of cyclictest command line arguments
  * fixed oscilloscope mode which didn't work correctly with more
    then one thread
* Wed May 14 2008 dgollub@suse.de
- updated to rt-tests 0.21
  * support for CPU affinity
- dropped memlock patch in favor of memlock patch by Clark Williams
- updated command arguments for cyclictest_run.sh for CPU affinity
* Thu May  8 2008 dgollub@suse.de
- added memlock option to lock the memory to avoid major pagefaults
* Tue Apr 22 2008 dgollub@suse.de
- removed ctcs2 glue subpackage
* Tue Apr 22 2008 dgollub@suse.de
- decreased the number of histogram samples from 20000 to 10000
  in cyclictest_run.sh
- fixed wrong escaping from in gnuplot script for ploting graph
  title in cyclictest_plot.sh
* Tue Apr 22 2008 dgollub@suse.de
- Avoid segfault of cyclictest if it gets immediately interrupted
  clock_nanosleep_interrupt.patch
* Fri Feb 29 2008 dgollub@suse.de
- Added ctcs glue subpackages
* Wed Feb 27 2008 dgollub@suse.de
- Added test helper scripts:
  * cyclictest_run.sh:
  calls cyclictests with adjusted number of CPUs and enables
  output of histogram
  * cyclictest_plot.sh
  generate a latency graph with the histogram output of cyclictests
- Fixed shebang of helper script and require for both script the first argument
  Otherwise print usage.
* Wed Feb 27 2008 dgollub@suse.de
- Added histogramm patch for cyclictest
* Tue Feb 26 2008 dgollub@suse.de
- disabled ia64, s390 and s390x for now to avoid build issues
  with struct sigevent and unionen member  _sigev_un._tid
* Thu Feb 21 2008 dgollub@suse.de
- initial checkin of rt-tests (Version 0.19)
